from typing import Union
from typing_extensions import Literal

from ..._models import BaseModel
from ...types.beta import (
    BetaMessage,
    BetaContentBlock,
    BetaRawMessageStopEvent,
    BetaRawMessageDeltaEvent,
    BetaRawMessageStartEvent,
    BetaRawContentBlockStopEvent,
    BetaRawContentBlockDeltaEvent,
    BetaRawContentBlockStartEvent,
)


class BetaTextEvent(BaseModel):
    type: Literal["text"]

    text: str
    """The text delta"""

    snapshot: str
    """The entire accumulated text"""


class BetaInputJsonEvent(BaseModel):
    type: Literal["input_json"]

    partial_json: str
    """A partial JSON string delta

    e.g. `'"San Francisco,'`
    """

    snapshot: object
    """The currently accumulated parsed object.


    e.g. `{'location': 'San Francisco, CA'}`
    """


class BetaMessageStopEvent(BetaRawMessageStopEvent):
    type: Literal["message_stop"]

    message: BetaMessage


class BetaContentBlockStopEvent(BetaRawContentBlockStopEvent):
    type: Literal["content_block_stop"]

    content_block: BetaContentBlock


BetaMessageStreamEvent = Union[
    BetaTextEvent,
    BetaInputJsonEvent,
    BetaRawMessageStartEvent,
    BetaRawMessageDeltaEvent,
    BetaMessageStopEvent,
    BetaRawContentBlockStartEvent,
    BetaRawContentBlockDeltaEvent,
    BetaContentBlockStopEvent,
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import Literal, TypeAlias

from ..._models import BaseModel
from .beta_text_delta import BetaTextDelta
from .beta_input_json_delta import BetaInputJSONDelta

__all__ = ["BetaRawContentBlockDeltaEvent", "Delta"]

Delta: TypeAlias = Union[BetaTextDelta, BetaInputJSONDelta]


class BetaRawContentBlockDeltaEvent(BaseModel):
    delta: Delta

    index: int

    type: Literal["content_block_delta"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._types import Base64FileInput
from ..._utils import PropertyInfo
from ..._models import set_pydantic_config

__all__ = ["BetaBase64PDFSourceParam"]


class BetaBase64PDFSourceParam(TypedDict, total=False):
    data: Required[Annotated[Union[str, Base64FileInput], PropertyInfo(format="base64")]]

    media_type: Required[Literal["application/pdf"]]

    type: Required[Literal["base64"]]


set_pydantic_config(BetaBase64PDFSourceParam, {"arbitrary_types_allowed": True})



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

from .base64_pdf_source_param import Base64PDFSourceParam
from .cache_control_ephemeral_param import CacheControlEphemeralParam

__all__ = ["DocumentBlockParam"]


class DocumentBlockParam(TypedDict, total=False):
    source: Required[Base64PDFSourceParam]

    type: Required[Literal["document"]]

    cache_control: Optional[CacheControlEphemeralParam]
